#!/bin/ksh
#######################################################################################
#
# IBM Enterprise Information Portal for Multiplatforms V6.1  (program number 5648-D03)
# (c ) Copyright IBM Corp. 1998, 1999.
# IBM Content Manager for Multiplatforms V6.1  (program number 5648-D04)
# (c ) Copyright IBM Corp. 1994, 1999.
#
# Licensed Materials - Property of IBM
# All Rights Reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corporation
#
###################################################################################
#***********************************************************************
# Program name  : in/cmxupdate.sh                                      *
#                                                                      *
#                                                                      *
# Description   : Apply the PTF Fixes                                  *
# Change History:                                                      *
#  110399 f17344 ckc  Initial                                          *
#***********************************************************************
#
# Get the current directory where the installation images are
#
#set -x
clear
if [[ $1 != "" ]] then
   FrnxImgDir=$1
else
   FrnxImgDir=`pwd`
fi


#
# Make sure "root" is the user ID
#

user=`whoami`
if [[ $user != "root" ]]; then
   echo "\nThe AIX 'root' user ID is required."
   echo "The current user ID, $user, can not perform the AIX installation function.\n"
   exit 1
fi # end of if current user is not root

if [[ -a /tmp/frnxinst$$.log ]] then
    /usr/bin/rm /tmp/frnxinst$$.log
fi

#
# Messages                                                              
#

msg1="No fileset(s) will be updated."
msg2="\nAbove fileset(s) exist on your machine.\nThey will be updated if fix are available on installation media.\nPress Enter to update. Press other key to quit.\n"
msg3="\n\nThe codes on your system have been updated."
msg4="has been updated successfully."
msg5="\nError occurred while updating "
msg6="Check "/tmp/frnxinst$$.log" for detail information."


#
# check component exists on local system
# display only the selectable ones
#

function checkcomp
{
 cd $FrnxImgDir
 for ptffile in `ls *.ptfimg`; do
     filesetname=`echo $ptffile | sed -e "s/.ptfimg//"`
     lslpp -l $filesetname > /dev/null 2>&1
     if [[ $? -eq 0 ]] then
        descrip1=`lslpp -l $filesetname | grep frn`
        descrip2=`lslpp -l $filesetname | grep cmb`
        descrip3=`lslpp -l $filesetname | grep COMMITTED`
        echo $descrip3 | grep frn > /dev/null 2>&1
        if [[ $? -eq 0 ]]; then
              echo $descrip3
        else
           if [[ "$descrip1" = "" ]]; then
	      echo $descrip2' '$descrip3
	   else
	      echo $descrip1' '$descrip3
           fi
        fi
        comp="$comp $filesetname " 
     fi
 done
}

#
# invoke installp to update files, will bring in the prereq if needed
#

function update
{
  #check if fix exists on installation media
  installp -L -d $FrnxImgDir | grep $xfs > /dev/null
  if [[ $? -eq 0 ]] 
  then 
      echo "Updating " $xfs
      installp -ac  -X -V2 -d $FrnxImgDir $xfs >> /tmp/frnxinst$$.log 2>&1
      if [[ $? -eq 0 ]] then
          echo $xfs $msg4
      else
          echo $msg5$xfs"."
          echo $msg6
      fi
  fi
}

#
# go through components and check if on the local system,
# if exists on the local system, store them in comp
#

comp=""
checkcomp

#
# if no component exists on the local system, exit
#

if [[ -z $comp ]] then
   echo $msg1
   exit
#
# if component exists on the local system, ready to update
# give the last opportunity for user to cancel/exit without installation        
#
else
   echo $msg2
   read x
   if [[ -n $x ]] then
   exit
   fi
fi

#
# update the components when fileset(s) was installed and Fixes available
#
for xfs in $comp
do
  update $xfs
done

#
# display post update message
#
echo $msg3

return 0
